library(readxl)
library(tidyr)
library(dplyr)
library(lessR)
style()
#Observational studies
#Plot ORs from Highly-cited studies and meta-analyses
Observational<- read_excel("Dropbox/Highly cited emotion papers/First2000 cit/Manuscript/Results/Synthetic table observational.xlsx", 
                           sheet = "ROR HC MA LS")
View(Observational)                                                              
names(Observational)
boxplot.stats(Observational$"HC OR")$out
# exclude 2 studies with very large HC OR (883.25 and 49.35) 
Observational_outlier<- filter(Observational, HC != 	"Hariri, 2002" & HC != "Breslau, 1991")
View (Observational_outlier)
HCOR <- Observational_outlier$`HC OR`
MAOR <- Observational_outlier$`MA OR`
HCearliest <- Observational_outlier$`HC=Earliest`

ScatterPlot (HCOR, MAOR, by =HCearliest, data = Observational_outlier,
             xlab = "Odds ratio in highly-cited studies" , ylab = "Odds ratio in meta-analyses",
            scale_x= c(0, 20, 20), scale_y= c(0, 10, 10), legend_title = "Highly-cited study first",
            add= "line", x1=0, y1=0, x2= 15, y2=15)

#Plot ORs from Highly-cited studies and largest studies in the meta-analysis
# Exclude cases where the highly-cited study is the largest study
Observational_excludeLSisHC <- filter(Observational, LS != "LS=HC")
boxplot.stats(Observational_excludeLSisHC$"HC OR")$out
# exclude 2 studies with very large HC OR (883.25 and 49.35) 
Observational_LS_outlier<- filter(Observational_excludeLSisHC, HC != 	"Hariri, 2002" & HC != "Breslau, 1991")
View (Observational_LS_outlier)
HCOR <- Observational_LS_outlier$`HC OR`
LSOR <- Observational_LS_outlier$`LS OR`
HCbeforeLS <- Observational_LS_outlier$`HC before LS`
ScatterPlot (HCOR, LSOR, by =HCbeforeLS, data = Observational_LS_outlier,
             xlab = "Odds ratio in highly-cited studies" , ylab = "Odds ratio in largest study",
             scale_x= c(0, 20, 20), scale_y= c(0, 10, 10), legend_title = "Highly-cited study first",
             add= "line", x1=0, y1=0, x2= 15, y2=15)

#Experimental studies
#Plot ORs from Highly-cited studies and meta-analyses
Experimental <- read_excel("Dropbox/Highly cited emotion papers/First2000 cit/Manuscript/Results/Synthetic table experimental.xlsx", 
                           sheet = "ROR HC MA LS")
View(Experimental)                                                              
names(Experimental)
boxplot.stats(Experimental$"HC OR")$out
HCOR <- Experimental$`HC OR`
MAOR <- Experimental$`MA OR`
HCearliest <- Experimental$`HC=Earliest`
ScatterPlot (HCOR, MAOR, by =HCearliest, data = Experimental,
             xlab = "Odds ratio in highly-cited studies" , ylab = "Odds ratio in meta-analyses",
             scale_x= c(0, 40, 20), scale_y= c(0, 24, 12), legend_title = "Highly-cited study first",
             add= "line", x1=0, y1=0, x2= 40, y2=40)

#Plot ORs from Highly-cited studies and largest studies in the meta-analysis
# Exclude cases where the highly-cited study is the largest study
Experimental_excludeLSisHC <- filter(Experimental, LS != "LS=HC")
boxplot.stats(Experimental_excludeLSisHC$"HC OR")$out

View (Experimental_excludeLSisHC)
HCOR <- Experimental_excludeLSisHC$`HC OR`
LSOR <- Experimental_excludeLSisHC$`LS OR`
HCbeforeLS <- Experimental_excludeLSisHC$`HC before LS`
ScatterPlot (HCOR, LSOR, by =HCbeforeLS, data = Experimental_excludeLSisHC,
             xlab = "Odds ratio in highly-cited studies" , ylab = "Odds ratio in largest study",
             scale_x= c(0, 40, 20), scale_y= c(0, 40, 20), legend_title = "Highly-cited study first",
             add= "line", x1=0, y1=0, x2= 40, y2=40)
